[![ci](https://img.shields.io/github/actions/workflow/status/betaboon/aio-microservice/ci.yaml?branch=main&style=for-the-badge)](https://github.com/betaboon/aio-microservice/actions/?query=branch%3Amain+workflow%3Aci)
[![pypi](https://img.shields.io/pypi/v/aio-microservice?style=for-the-badge)](https://pypi.org/project/aio-microservice/)
[![pyversions](https://img.shields.io/pypi/pyversions/aio-microservice?style=for-the-badge)](https://github.com/betaboon/aio-microservice)
[![license](https://img.shields.io/github/license/betaboon/aio-microservice?style=for-the-badge)](https://github.com/betaboon/aio-microservice/LICENSE)

---

**Documentation**: <a href="https://betaboon.github.io/aio-microservice" target="_blank">https://betaboon.github.io/aio-microservice</a>

**Source Code**: <a href="https://github.com/betaboon/aio-microservice" target="_blank">https://github.com/betaboon/aio-microservice</a>

---

# AIO Microservice
<!-- start description -->

A library to create microservices.

<!-- end description -->

## Features
<!-- start features -->

- TODO

<!-- end features -->

## Installation
<!-- start installation -->

AIO Microservice can be installed with `pip`:

```text
pip install aio-microservice
```

<!-- end installation -->

## Quickstart
<!-- start quickstart -->

<!-- end quickstart -->

## Contributing
